from distutils.core import setup

setup(
    name='saganvm',
    version='1.1.5',
    packages=['sagan'],
    url='',
    license='',
    author='T A H Smith, A W Collins',
    author_email='saganvirtual@cuberider.com',
    description='Python library for interfacing with launchpad website')
